==> centreon-web-23.10.24.tar.gz: centreon-web-23.10.24/www/class/centreonDBInstance.class.php <==
<?php
/*
 * Copyright 2005-2015 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

// file centreon.config.php may not exist in test environment
$configFile = realpath(dirname(__FILE__) . "/../../config/centreon.config.php");
if ($configFile !== false) {
    include_once $configFile;
}

require_once realpath(dirname(__FILE__) . "/centreonDB.class.php");

class CentreonDBInstance
{
    private static $confInstance;
    private static $monInstance;

    private $instance;

    /**
     * CentreonDBInstance constructor.
     * @param string $db
     */
    private function __construct($db = "centreon")
    {
        $this->instance = new \CentreonDB($db);
    }

    public function getInstance()
    {
        return $this->instance;
    }

    public static function getConfInstance()
    {
        if (is_null(self::$confInstance)) {
            self::$confInstance = new \CentreonDBInstance('centreon');
        }
        return self::$confInstance->getInstance();
    }

    public static function getMonInstance()
    {
        if (is_null(self::$monInstance)) {
            self::$monInstance = new \CentreonDBInstance('centstorage');
        }
        return self::$monInstance->getInstance();
    }
}

==> centreon-web-24.10.17.tar.gz: centreon-web-24.10.17/www/class/centreonDBInstance.class.php <==
<?php
/*
 * Copyright 2005-2015 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

// file centreon.config.php may not exist in test environment
$configFile = realpath(__DIR__ . "/../../config/centreon.config.php");
if ($configFile !== false) {
    include_once $configFile;
}

require_once realpath(__DIR__ . "/centreonDB.class.php");

/**
 * Class
 *
 * @class CentreonDBInstance
 */
class CentreonDBInstance
{
    /** @var CentreonDBInstance */
    private static $dbCentreonInstance;
    /** @var CentreonDBInstance */
    private static $dbCentreonStorageInstance;
    /** @var CentreonDB */
    private $instance;

    /**
     * CentreonDBInstance constructor.
     *
     * @param string $db
     *
     * @throws Exception
     */
    private function __construct($db = "centreon")
    {
        $this->instance = new \CentreonDB($db);
    }

    /**
     * @return CentreonDB
     */
    public function getInstance()
    {
        return $this->instance;
    }

    /**
     * @return CentreonDB
     */
    public static function getDbCentreonInstance()
    {
        if (is_null(self::$dbCentreonInstance)) {
            self::$dbCentreonInstance = new \CentreonDBInstance('centreon');
        }
        return self::$dbCentreonInstance->getInstance();
    }

    /**
     * @return CentreonDB
     */
    public static function getDbCentreonStorageInstance()
    {
        if (is_null(self::$dbCentreonStorageInstance)) {
            self::$dbCentreonStorageInstance = new \CentreonDBInstance('centstorage');
        }
        return self::$dbCentreonStorageInstance->getInstance();
    }
}
